.. ontmont documentation master file, created by
   sphinx-quickstart on Mon Jun 10 11:07:42 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ontmont's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   ontmont
   modules

.. include:: ../README.md
   :parser: myst_parser.sphinx_
   :start-after: <!-- index.rst content start -->

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
